﻿using RenovationWorkContracts.BindingModels;
using RenovationWorkContracts.SearchModels;
using RenovationWorkContracts.StoragesContracts;
using RenovationWorkContracts.ViewModels;
using RenovationWorkListImplement.Models;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace RenovationWorkListImplement.Implements
{
    public class RepairStorage : IRepairStorage
    {
        private readonly DataListSingleton _source;

        public RepairStorage()
        {
            _source = DataListSingleton.GetInstance();
        }

        public List<RepairViewModel> GetFullList()
        {
            var result = new List<RepairViewModel>();
            foreach (var repairs in _source.Repairs)
            {
                result.Add(repairs.GetViewModel);
            }
            return result;
        }

        public List<RepairViewModel> GetFilteredList(RepairSearchModel model)
        {
            var result = new List<RepairViewModel>();
            if (string.IsNullOrEmpty(model.RepairName))
            {
                return result;
            }
            foreach (var repairs in _source.Repairs)
            {
                if (repairs.RepairName.Contains(model.RepairName))
                {
                    result.Add(repairs.GetViewModel);
                }
            }
            return result;
        }

        public RepairViewModel? GetElement(RepairSearchModel model)
        {
            if (string.IsNullOrEmpty(model.RepairName) && !model.Id.HasValue)
            {
                return null;
            }
            foreach (var repairs in _source.Repairs)
            {
                if ((!string.IsNullOrEmpty(model.RepairName) && repairs.RepairName == model.RepairName) ||
                    (model.Id.HasValue && repairs.Id == model.Id))
                {
                    return repairs.GetViewModel;
                }
            }
            return null;
        }

        public RepairViewModel? Insert(RepairBindingModel model)
        {
            model.Id = 1;
            foreach (var repairs in _source.Repairs)
            {
                if (model.Id <= repairs.Id)
                {
                    model.Id = repairs.Id + 1;
                }
            }
            var newRepairs = Repair.Create(model);
            if (newRepairs == null)
            {
                return null;
            }
            _source.Repairs.Add(newRepairs);
            return newRepairs.GetViewModel;
        }

        public RepairViewModel? Update(RepairBindingModel model)
        {
            foreach (var repairs in _source.Repairs)
            {
                if (repairs.Id == model.Id)
                {
                    repairs.Update(model);
                    return repairs.GetViewModel;
                }
            }
            return null;
        }

        public RepairViewModel? Delete(RepairBindingModel model)
        {
            for (int i = 0; i < _source.Repairs.Count; ++i)
            {
                if (_source.Repairs[i].Id == model.Id)
                {
                    var element = _source.Repairs[i];
                    _source.Repairs.RemoveAt(i);
                    return element.GetViewModel;
                }
            }
            return null;
        }
    }
}
